"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class ExpiryMap {
    constructor(maxAge, data) {
        this.maxAge = maxAge;
        this[Symbol.toStringTag] = 'Map';
        this.data = new Map();
        if (data) { // tslint:disable-line:early-exit
            for (const [key, value] of data) {
                this.set(key, value);
            }
        }
    }
    get size() {
        return [...this.entries()].length;
    }
    clear() {
        this.data.clear();
    }
    delete(key) {
        return this.data.delete(key);
    }
    has(key) {
        const value = this.data.get(key);
        return Boolean(value && !this.isExpired([key, value]));
    }
    get(key) {
        const value = this.data.get(key);
        if (value && !this.isExpired([key, value])) {
            return value.data;
        }
        return;
    }
    set(key, value) {
        this.data.set(key, {
            timestamp: Date.now(),
            data: value
        });
        return this;
    }
    values() {
        return this.createIterator(item => item[1].data);
    }
    keys() {
        return this.createIterator(item => item[0]);
    }
    entries() {
        return this.createIterator(item => [item[0], item[1].data]);
    }
    forEach(callbackfn, thisArg) {
        for (const [key, value] of this.entries()) {
            callbackfn.apply(thisArg, [value, key, this]);
        }
    }
    [Symbol.iterator]() {
        return this.entries();
    }
    isExpired([key, value]) {
        const isExpired = Date.now() - value.timestamp > this.maxAge;
        if (isExpired) {
            this.data.delete(key);
        }
        return isExpired;
    }
    *createIterator(projection) {
        for (const item of this.data.entries()) {
            if (!this.isExpired(item)) {
                yield projection(item);
            }
        }
    }
}
exports.default = ExpiryMap;
// Add support for CJS
module.exports = ExpiryMap;
module.exports.default = ExpiryMap;
